#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-HYXnqKpDNof693jkKUc5xh
key:                  coinbase-pro-0.9.3.2-HYXnqKpDNof693jkKUc5xh
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  577aeb3d5ff7ec7ffa356dc50eb24258
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-HYXnqKpDNof693jkKUc5xh
depends:
    HsOpenSSL-0.11.7.9-E6m6SgUkWYU3DHIBjAKRuk
    aeson-2.2.1.0-A71cfLUaGyLArzjDm23YCT
    aeson-casing-0.2.0.0-6dEKqIUHcx3aHQXz9qToM
    async-2.2.6-IXER6sJdc7YHGmcgizEodd base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-IfE5ifcwUl3KPbanvIFJlO exceptions-0.10.7
    http-api-data-0.6.1-69au1pscIXP6oc0Q8PhC7W
    http-client-0.7.19-9FTYcfIpKGiHy9Ae0QYZtZ
    http-client-tls-0.3.6.4-20BoFilNt6wH0DhGvOn6jR
    http-streams-0.8.9.9-EIOW7VhmUnH9MHaz5YKOFM
    http-types-0.12.4-L2YTfMIRXR15iGgrvyaAXo
    io-streams-1.5.2.2-7q3N6mi2oqdDkk4wCGA8sS
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-FNXzQuurZ9fI5swP2Jnlmv
    servant-0.20.3.0-HEhSrgDVGj9LSomQqSkbH5
    servant-client-0.20.3.0-BQ49cs0LneFKnHjOLJzJIk
    servant-client-core-0.20.3.0-8yagr7YXowcEQ4Nz6dPOAI
    tasty-1.5.2-FhQxW1F8kTZC70FeLaA0bQ
    tasty-hunit-0.10.2-DhLzMlVyrqV57OIMd3nsa2 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-GzN2UCePQy1I0VApPqw6HA
    unordered-containers-0.2.20.1-2gLa11KPU9tAOCQUon3yBM
    uuid-1.3.16.1-HqvO2ylC8LwJrSxdLHFr3Z
    vector-0.13.2.0-H6NBNEnsmKX3uzoVjJAmgG
    websockets-0.12.7.3-8RjVrWXazlqKW8v4Mds7py
    wuss-2.0.1.6-8CknPYLtZknJdOjoeNU5VX

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

